@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003, 2004 GraphicsMagick Group
+  Copyright (C) 2003 GraphicsMagick Group
   Copyright (C) 2002 ImageMagick Studio
   Copyright 1991-1999 E. I. du Pont de Nemours and Company
  
@@ -34,11 +34,12 @@ extern "C" {
   identifying the release.
 */
 #define MagickPackageName "GraphicsMagick"
-#define MagickCopyright  "Copyright (C) 2002, 2003, 2004 " MagickPackageName " Group"
-#define MagickLibVersion  0x000007
-#define MagickLibVersionText  "1.0.5"
-#define MagickLibVersionNumber 0,0,7
-#define MagickReleaseDate  "November 26, 2004"
+#define MagickCopyright  "Copyright (C) 2002-2007 GraphicsMagick Group.\nAdditional copyrights and licenses apply to this software.\nSee http://www.GraphicsMagick.org/www/Copyright.html for details."
+#define MagickLibVersion  0x010009
+#define MagickLibVersionText  "1.1.9"
+#define MagickLibVersionNumber 1,0,9
+#define MagickChangeDate   "20070916"
+#define MagickReleaseDate  "2007-09-16"
 
 
 #if (QuantumDepth == 8)
