@@ -7,23 +7,36 @@
 # Package base name
 PACKAGE_NAME='GraphicsMagick'
 #
-# Package version.  This is is the numeric version suffix applied to
-# PACKAGE_NAME (e.g. "1.0").
-PACKAGE_VERSION='1.0.5'
+# Package base version.  This is is the numeric version suffix applied to
+# PACKAGE_NAME (e.g. "1.1").
+PACKAGE_VERSION='1.1.9'
 
 #
 # Formal Package release date
-PACKAGE_RELEASE_DATE="November 26, 2004"
+# Set to string "unreleased" if package is not a formal release.
+PACKAGE_RELEASE_DATE="2007-09-16"
+#PACKAGE_RELEASE_DATE="unreleased"
 
 #
-# Package version addendum.  This is an arbitrary suffix (if any)
-# appended to the package version. (e.g. "beta1")
-# Extract the most recent update date from the ChangeLog
-CHANGE_DATE=`awk '/^[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]/ { print substr($1,1,4) substr($1,6,2) substr($1,9,2); exit; }' ${srcdir}/ChangeLog`
-PACKAGE_VERSION_ADDENDUM="-${CHANGE_DATE}"
+# Date of last ChangeLog update
+#
+PACKAGE_CHANGE_DATE=`awk '/^[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]/ { print substr($1,1,4) substr($1,6,2) substr($1,9,2); exit; }' ${srcdir}/ChangeLog`
 
-# To hardcode the version addendum, uncomment the following line
-PACKAGE_VERSION_ADDENDUM=''
+#
+# Package version addendum.  This is a suffix (if any) appended to the
+# package base version.  Formal releases do not have a suffix applied.
+#
+if test "$PACKAGE_RELEASE_DATE" = ""
+then
+  PACKAGE_VERSION_ADDENDUM=".0${PACKAGE_CHANGE_DATE}"
+else
+  PACKAGE_VERSION_ADDENDUM=''
+fi
+
+#
+# CVS branch that this release is on.
+#
+CVS_BRANCH_TAG=GraphicsMagick-1_1
 
 #
 # Libtool library revision control info
@@ -45,7 +58,24 @@ PACKAGE_VERSION_ADDENDUM=''
 #     increment age.
 #  6. If any interfaces have been removed since the last public release,
 #     then set age to 0.
-LIBRARY_CURRENT=0
-LIBRARY_REVISION=7
-LIBRARY_AGE=0
 
+#
+# Magick library versioning
+#
+MAGICK_LIBRARY_CURRENT=1
+MAGICK_LIBRARY_REVISION=9
+MAGICK_LIBRARY_AGE=0
+
+#
+# Magick++ library versioning
+#
+MAGICK_PLUS_PLUS_LIBRARY_CURRENT=1
+MAGICK_PLUS_PLUS_LIBRARY_REVISION=3
+MAGICK_PLUS_PLUS_LIBRARY_AGE=0
+
+#
+# Magick Wand library versioning
+#
+MAGICK_WAND_LIBRARY_CURRENT=0
+MAGICK_WAND_LIBRARY_REVISION=4
+MAGICK_WAND_LIBRARY_AGE=0
